@@ -12,7 +12,7 @@ use vars qw
 use Exporter;
 use AutoLoader qw( AUTOLOAD );
 use Handy::Dandy qw( :all );
-$VERSION    = 3.13_9; # 12/23/02, 3:22 pm
+$VERSION    = 3.13_8; # 12/22/02, 11:31 pm
 @ISA        = qw( Exporter   Handy::Dandy );
 @EXPORT_OK  =
    (
@@ -1145,11 +1145,13 @@ sub can_flock { $CAN_FLOCK }
 # --------------------------------------------------------
 sub created {
 
-   my($f) = myargs(@_); $f ||= '';
+   my($f,$fmt) = myargs(@_); $f ||= '';
 
    return undef unless -e $f;
 
-   $^T - ((-M $f) * 60 * 60 * 24)
+   my($r) = $^T - ((-M $f) * 60 * 60 * 24);
+
+   $fmt ? stamp($r,$fmt) : $r
 }
 
 
@@ -1264,12 +1266,14 @@ sub isbin { my($f) = myargs(@_); -B $f }
 # --------------------------------------------------------
 sub last_access {
 
-   my($f) = myargs(@_); $f ||= '';
+   my($f,$fmt) = myargs(@_); $f ||= '';
 
    return undef unless -e $f;
 
    # return the last accessed time of $f
-   $^T - ((-A $f) * 60 * 60 * 24)
+   my($r) = $^T - ((-A $f) * 60 * 60 * 24);
+
+   $fmt ? stamp($r,$fmt) : $r
 }
 
 
@@ -1278,11 +1282,13 @@ sub last_access {
 # --------------------------------------------------------
 sub last_mod {
 
-   my($f) = myargs(@_); $f ||= '';
+   my($f,$fmt) = myargs(@_); $f ||= '';
 
    return undef unless -e $f;
 
-   $^T - ((-C $f) * 60 * 60 * 24)
+   my($r) = $^T - ((-C $f) * 60 * 60 * 24);
+
+   $fmt ? stamp($r,$fmt) : $r
 }
 
 
@@ -2297,28 +2303,22 @@ __bad_handle__
 =pod
 
 =head1 NAME
-
 File::Util - Easy, versatile, portable file handling.
 
 =head1 VERSION
-
-3.13_9
+3.13_8
 
 =head1 @ISA
-
    Exporter
    Handy::Dandy
       |
       +->OOorNO
+         Handy::Dandy::TimeTools
 
 =head1 @EXPORT
-
 None by default.
 
 =head1 @EXPORT_OK
-
-   @OOorNO::EXPORT_OK
-   @Handy::Dandy::EXPORT_OK
    bitmask()
    can_flock()
    can_read()
@@ -2335,13 +2335,51 @@ None by default.
    SL
    strip_path()
    valid_filename()
+   @Handy::Dandy::EXPORT_OK
+      |
+      +->convert_size()
+         html_encode()
+         html_escape()
+         isfloat()
+         isin()
+         isint()
+         isnum()
+         touch()
+         trim()
+         use_once()
+         utf8()
+         @OOorNO::EXPORT_OK
+            |
+            +->coerce_array
+               myargs()
+               myself()
+               OOorNO()
+               shave_opts()
+         @Handy::Dandy::TimeTools::EXPORT_OK
+            |
+            +->convert_time()
+               dayofweek()
+               dayofyear()
+               daystart()
+               hour()
+               hourstart()
+               minute()
+               minutestart()
+               month()
+               monthstart()
+               second()
+               seconds_since()
+               stamp()
+               to_seconds()
+               UTC_OFFSET()
+               weekstart()
+               year()
+               yearstart()
 
 =head1 %EXPORT_TAGS
-
    :all (exports all of @File::Util::EXPORT_OK)
 
 =head1 Methods
-
    _dropdots()
    _errors()
    _release()
@@ -2380,7 +2418,6 @@ None by default.
    VERSION()
 
 =head2 AUTOLOAD-ed methods
-
    bitmask()
    can_flock()
    created()
@@ -2406,22 +2443,19 @@ None by default.
    _errors()
 
 =head1 PREREQUISITES
-
 Perl 5.006 or better
 OOorNO.pm
-Exception::Handler.pm
+Exception::Handler
 Handy::Dandy.pm
+Handy::Dandy::TimeTools.pm
 
 =head1 AUTHOR
-
 Tommy Butler <cpan@atrixnet.com>
 
 =head1 COPYRIGHT
-
 Copyright(c) 2001-2003, Tommy Butler.  All rights reserved.
 
 =head1 LICENSE
-
 This library is free software, you may redistribute
 and/or modify it under the same terms as Perl itself.
 
